==> eboard-0.3.3.tar.gz: eboard-0.3.3/dlg_connect.cc <==
/* $Id: dlg_connect.cc,v 1.7 2001/06/18 16:41:22 bergo Exp $ */

/*

    eboard - chess client
    http://eboard.sourceforge.net
    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
    bergo@seul.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#include <iostream.h>
#include <stdlib.h>
#include <string.h>
#include "stl.h"
#include "dlg_connect.h"
#include "protocol.h"
#include "global.h"

ConnectDialog::ConnectDialog() {
  GtkWidget *v,*hs,*hb,*ok,*cancel;
  GtkWidget *zh,*zv,*ysw,*ysl;
  BoxedLabel *bl[3];
  GList *combo;
  char z[64];
  int i;

  widget=gtk_window_new(GTK_WINDOW_DIALOG);
  //gtk_window_set_transient_for(GTK_WINDOW(dlg),MainWindow);
  if (!global.HostHistory.empty())
    gtk_window_set_default_size(GTK_WINDOW(widget),400,250);
  gtk_window_set_title(GTK_WINDOW(widget),"Connect to ICS Server");
  gtk_window_set_position(GTK_WINDOW(widget),GTK_WIN_POS_CENTER);
  gtk_container_set_border_width(GTK_CONTAINER(widget),4);
  gtk_widget_realize(widget);

  v=gtk_vbox_new(FALSE,4);
  gtk_container_add(GTK_CONTAINER(widget),v);

  zh=gtk_hbox_new(FALSE,4);
  zv=gtk_vbox_new(FALSE,4);

  gtk_box_pack_start(GTK_BOX(v),zh,TRUE,TRUE,0);

  if (!global.HostHistory.empty()) {   
    ysw=gtk_scrolled_window_new(0,0);
    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(ysw),
				   GTK_POLICY_AUTOMATIC,
				   GTK_POLICY_AUTOMATIC);

    ysl=gtk_clist_new(1);
    gtk_clist_set_column_title(GTK_CLIST(ysl),0,"Recent Hosts");
    gtk_clist_set_selection_mode(GTK_CLIST(ysl),GTK_SELECTION_SINGLE);
    gtk_clist_column_titles_show(GTK_CLIST(ysl));

    char z[256];
    char *zp[1];
    for(list<HostBookmark *>::iterator bi=global.HostHistory.begin();
	bi!=global.HostHistory.end();bi++) {
      sprintf(z,"%s, %d, %s",(*bi)->host,(*bi)->port,(*bi)->protocol);
      zp[0]=z;
      gtk_clist_append(GTK_CLIST(ysl),zp);
    }

    gtk_container_add(GTK_CONTAINER(ysw),ysl);
    gtk_box_pack_start(GTK_BOX(zh),ysw,TRUE,TRUE,4);    

    gtk_signal_connect(GTK_OBJECT(ysl),"select_row",
		       GTK_SIGNAL_FUNC(dlgconn_rowsel),this);

    gtk_widget_show(ysl);
    gtk_widget_show(ysw);
  }

  gtk_box_pack_start(GTK_BOX(zh),zv,FALSE,TRUE,0);  

  bl[0]=new BoxedLabel("Hostname");
  bl[1]=new BoxedLabel("TCP Port");
  bl[2]=new BoxedLabel("Protocol");

  server=gtk_entry_new();
  port=gtk_entry_new();
  protocol=gtk_combo_new();

  combo=0;
  combo=g_list_append(combo,(gpointer)"FICS");
  combo=g_list_append(combo,(gpointer)"FICS without timeseal");
  gtk_combo_set_popdown_strings(GTK_COMBO(protocol),combo);
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(protocol)->entry),"FICS");
  gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(protocol)->entry),FALSE);

  gtk_box_pack_start(GTK_BOX(zv),bl[0]->widget,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),server,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),bl[1]->widget,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),port,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),bl[2]->widget,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),protocol,FALSE,FALSE,0);

  gtk_entry_set_text(GTK_ENTRY(port),"5000");

  hs=gtk_hseparator_new();
  gtk_box_pack_start(GTK_BOX(v),hs,FALSE,FALSE,6);

  hb=gtk_hbutton_box_new();
  gtk_button_box_set_layout(GTK_BUTTON_BOX(hb), GTK_BUTTONBOX_END);
  gtk_button_box_set_spacing(GTK_BUTTON_BOX(hb), 5);

  gtk_box_pack_start(GTK_BOX(v),hb,FALSE,FALSE,2);
  
  ok=gtk_button_new_with_label("Connect");
  GTK_WIDGET_SET_FLAGS(ok,GTK_CAN_DEFAULT);
  cancel=gtk_button_new_with_label("Cancel");
  GTK_WIDGET_SET_FLAGS(cancel,GTK_CAN_DEFAULT);

  gtk_box_pack_start(GTK_BOX(hb),ok,TRUE,TRUE,0);
  gtk_box_pack_start(GTK_BOX(hb),cancel,TRUE,TRUE,0);

  gtk_widget_grab_default(ok);

  for(i=0;i<3;i++)
    gtk_widget_show(bl[i]->widget);
  gtk_widget_show(server);
  gtk_widget_show(port);
  gtk_widget_show(protocol);
  gtk_widget_show(hs);
  gtk_widget_show(hb);
  gtk_widget_show(cancel);
  gtk_widget_show(ok);

  gtk_widget_show(zv);
  gtk_widget_show(zh);
  gtk_widget_show(v);

  gtk_signal_connect(GTK_OBJECT(ok),"clicked",
		     GTK_SIGNAL_FUNC(dlg_connect_ok),this);
  gtk_signal_connect(GTK_OBJECT(cancel),"clicked",
		     GTK_SIGNAL_FUNC(dlg_connect_cancel),this);
}

void ConnectDialog::show() {
  gtk_widget_show(widget);
  gtk_grab_add(widget);
  gtk_widget_grab_focus(server);
}

void dlg_connect_ok(GtkWidget *w,gpointer data) {
  int useseal=1;
  ConnectDialog *cd;
  ProtocolParser *pp;
  HostBookmark *hbm;
  cd=(ConnectDialog *)data;
  strncpy(cd->Host,gtk_entry_get_text(GTK_ENTRY(cd->server)),256);
  cd->Port=atoi(gtk_entry_get_text(GTK_ENTRY(cd->port)));
  strncpy(cd->Proto,
	  gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(cd->protocol)->entry)),64);  

  hbm=new HostBookmark();
  strcpy(hbm->host,cd->Host);
  hbm->port=cd->Port;
  strcpy(hbm->protocol,cd->Proto);
  global.addHostBookmark(hbm);

  pp=0;
  if (!strcmp(cd->Proto,"FICS without timeseal")) {
    pp=new FicsProtocolParser();
    useseal=0;
    goto kissagirl;
  }

  if (!strcmp(cd->Proto,"FICS")) {
    pp=new FicsProtocolParser();
    useseal=1;
    goto kissagirl;
  }
  if (!pp)
    pp=new NullProtocolParser();

 kissagirl:

  gtk_grab_remove(cd->widget);
  gtk_widget_destroy(cd->widget);

  if (useseal)
    global.chandler->openServer(cd->Host,cd->Port,pp,"timeseal");
  else
    global.chandler->openServer(cd->Host,cd->Port,pp,0);
}

void dlg_connect_cancel(GtkWidget *w,gpointer data) {
  ConnectDialog *cd;
  cd=(ConnectDialog *)data;
  gtk_grab_remove(cd->widget);
  gtk_widget_destroy(cd->widget);
}

void dlgconn_rowsel(GtkCList *clist,int row,int column,GdkEventButton *eb,
		    gpointer data) {
  ConnectDialog *me;
  list<HostBookmark *>::iterator bi;
  char z[6];
  me=(ConnectDialog *)data;

  for(bi=global.HostHistory.begin();row;row--)
    bi++;

  gtk_entry_set_text(GTK_ENTRY(me->server),(*bi)->host);
  sprintf(z,"%d",(*bi)->port);
  gtk_entry_set_text(GTK_ENTRY(me->port),z);
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(me->protocol)->entry),(*bi)->protocol);
}

==> eboard_0.4.3.orig.tar.gz: eboard-0.4.3/dlg_connect.cc <==
/* $Id: dlg_connect.cc,v 1.9 2002/03/12 02:03:23 bergo Exp $ */

/*

    eboard - chess client
    http://eboard.sourceforge.net
    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
    bergo@seul.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#include <iostream.h>
#include <stdlib.h>
#include <string.h>
#include "stl.h"
#include "dlg_connect.h"
#include "protocol.h"
#include "global.h"

ConnectDialog::ConnectDialog() {
  GtkWidget *v,*hs,*hb,*ok,*cancel,*t;
  GtkWidget *zh,*zv,*ysw,*ysl;
  BoxedLabel *bl[3];
  GList *combo;
  char z[64];
  int i;

  widget=gtk_window_new(GTK_WINDOW_DIALOG);
  //gtk_window_set_transient_for(GTK_WINDOW(dlg),MainWindow);
  if (!global.HostHistory.empty())
    gtk_window_set_default_size(GTK_WINDOW(widget),400,300);
  gtk_window_set_title(GTK_WINDOW(widget),"Connect to ICS Server");
  gtk_window_set_position(GTK_WINDOW(widget),GTK_WIN_POS_CENTER);
  gtk_container_set_border_width(GTK_CONTAINER(widget),4);
  gtk_widget_realize(widget);

  v=gtk_vbox_new(FALSE,4);
  gtk_container_add(GTK_CONTAINER(widget),v);

  zh=gtk_hbox_new(FALSE,4);
  zv=gtk_vbox_new(FALSE,4);

  gtk_box_pack_start(GTK_BOX(v),zh,TRUE,TRUE,0);

  if (!global.HostHistory.empty()) {   
    ysw=gtk_scrolled_window_new(0,0);
    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(ysw),
				   GTK_POLICY_AUTOMATIC,
				   GTK_POLICY_AUTOMATIC);

    ysl=gtk_clist_new(1);
    gtk_clist_set_column_title(GTK_CLIST(ysl),0,"Recent Hosts");
    gtk_clist_set_selection_mode(GTK_CLIST(ysl),GTK_SELECTION_SINGLE);
    gtk_clist_column_titles_show(GTK_CLIST(ysl));

    char z[256];
    char *zp[1];
    for(list<HostBookmark *>::iterator bi=global.HostHistory.begin();
	bi!=global.HostHistory.end();bi++) {
      sprintf(z,"%s, %d, %s",(*bi)->host,(*bi)->port,(*bi)->protocol);
      zp[0]=z;
      gtk_clist_append(GTK_CLIST(ysl),zp);
    }

    gtk_container_add(GTK_CONTAINER(ysw),ysl);
    gtk_box_pack_start(GTK_BOX(zh),ysw,TRUE,TRUE,4);    

    gtk_signal_connect(GTK_OBJECT(ysl),"select_row",
		       GTK_SIGNAL_FUNC(dlgconn_rowsel),this);

    gtk_widget_show(ysl);
    gtk_widget_show(ysw);
  }

  gtk_box_pack_start(GTK_BOX(zh),zv,FALSE,TRUE,0);  

  bl[0]=new BoxedLabel("Hostname");
  bl[1]=new BoxedLabel("TCP Port");
  bl[2]=new BoxedLabel("Protocol");

  server=gtk_entry_new();
  port=gtk_entry_new();
  protocol=gtk_combo_new();

  combo=0;
  combo=g_list_append(combo,(gpointer)"FICS");
  combo=g_list_append(combo,(gpointer)"FICS without timeseal");
  gtk_combo_set_popdown_strings(GTK_COMBO(protocol),combo);
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(protocol)->entry),"FICS");
  gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(protocol)->entry),FALSE);

  gtk_box_pack_start(GTK_BOX(zv),bl[0]->widget,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),server,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),bl[1]->widget,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),port,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),bl[2]->widget,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(zv),protocol,FALSE,FALSE,0);

  gtk_entry_set_text(GTK_ENTRY(port),"5000");

  t=gtk_label_new("Once you connect to a host from this dialog, it will be added to\n"\
		  "the Peer/ICS Bookmarks menu. Edit the ~/.eboard/eboard.conf file\n"\
		  "to modify or remove entries.");
  gtk_box_pack_start(GTK_BOX(v),t,FALSE,FALSE,6);

  hs=gtk_hseparator_new();
  gtk_box_pack_start(GTK_BOX(v),hs,FALSE,FALSE,6);

  hb=gtk_hbutton_box_new();
  gtk_button_box_set_layout(GTK_BUTTON_BOX(hb), GTK_BUTTONBOX_END);
  gtk_button_box_set_spacing(GTK_BUTTON_BOX(hb), 5);

  gtk_box_pack_start(GTK_BOX(v),hb,FALSE,FALSE,2);
  
  ok=gtk_button_new_with_label("Connect");
  GTK_WIDGET_SET_FLAGS(ok,GTK_CAN_DEFAULT);
  cancel=gtk_button_new_with_label("Cancel");
  GTK_WIDGET_SET_FLAGS(cancel,GTK_CAN_DEFAULT);

  gtk_box_pack_start(GTK_BOX(hb),ok,TRUE,TRUE,0);
  gtk_box_pack_start(GTK_BOX(hb),cancel,TRUE,TRUE,0);

  gtk_widget_grab_default(ok);

  for(i=0;i<3;i++)
    gtk_widget_show(bl[i]->widget);
  gtk_widget_show(server);
  gtk_widget_show(port);
  gtk_widget_show(protocol);
  gtk_widget_show(t);
  gtk_widget_show(hs);
  gtk_widget_show(hb);
  gtk_widget_show(cancel);
  gtk_widget_show(ok);

  gtk_widget_show(zv);
  gtk_widget_show(zh);
  gtk_widget_show(v);

  gtk_signal_connect(GTK_OBJECT(ok),"clicked",
		     GTK_SIGNAL_FUNC(dlg_connect_ok),this);
  gtk_signal_connect(GTK_OBJECT(cancel),"clicked",
		     GTK_SIGNAL_FUNC(dlg_connect_cancel),this);
}

void ConnectDialog::show() {
  gtk_widget_show(widget);
  gtk_grab_add(widget);
  gtk_widget_grab_focus(server);
}

void dlg_connect_ok(GtkWidget *w,gpointer data) {
  int useseal=1;
  ConnectDialog *cd;
  ProtocolParser *pp;
  HostBookmark *hbm;
  TString t(256);

  cd=(ConnectDialog *)data;
  strncpy(cd->Host,gtk_entry_get_text(GTK_ENTRY(cd->server)),256);
  cd->Port=atoi(gtk_entry_get_text(GTK_ENTRY(cd->port)));
  strncpy(cd->Proto,
	  gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(cd->protocol)->entry)),64);  

  t.set(cd->Host);
  if (t.token(" \n\t\r") == 0) {
    return;
  }

  hbm=new HostBookmark();
  strcpy(hbm->host,cd->Host);
  hbm->port=cd->Port;
  strcpy(hbm->protocol,cd->Proto);
  global.addHostBookmark(hbm);

  pp=0;
  if (!strcmp(cd->Proto,"FICS without timeseal")) {
    pp=new FicsProtocolParser();
    useseal=0;
    goto kissagirl;
  }

  if (!strcmp(cd->Proto,"FICS")) {
    pp=new FicsProtocolParser();
    useseal=1;
    goto kissagirl;
  }
  if (!pp)
    pp=new NullProtocolParser();

 kissagirl:

  gtk_grab_remove(cd->widget);
  gtk_widget_destroy(cd->widget);

  if (useseal)
    global.chandler->openServer(cd->Host,cd->Port,pp,"timeseal");
  else
    global.chandler->openServer(cd->Host,cd->Port,pp,0);
}

void dlg_connect_cancel(GtkWidget *w,gpointer data) {
  ConnectDialog *cd;
  cd=(ConnectDialog *)data;
  gtk_grab_remove(cd->widget);
  gtk_widget_destroy(cd->widget);
}

void dlgconn_rowsel(GtkCList *clist,int row,int column,GdkEventButton *eb,
		    gpointer data) {
  ConnectDialog *me;
  list<HostBookmark *>::iterator bi;
  char z[6];
  me=(ConnectDialog *)data;

  for(bi=global.HostHistory.begin();row;row--)
    bi++;

  gtk_entry_set_text(GTK_ENTRY(me->server),(*bi)->host);
  sprintf(z,"%d",(*bi)->port);
  gtk_entry_set_text(GTK_ENTRY(me->port),z);
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(me->protocol)->entry),(*bi)->protocol);
}
